<?php namespace Helper\MetadataGenerator\Metadata\General;
    
    use Helper\MetadataGenerator\Metadata\Utils\Utils;

    class General {
        /**
        * @var string
        */
        public $title = "";
        /**
        * @var string
        */
        public $charset = "utf-8";
        /**
        * @var string
        */
        public $description = "";
        /**
        * @var string
        */
        public $keywords = "";
        /**
        * @var string
        */
        public $author = "";
        /**
        * @var string
        */
        public $themeColor = "";
        /**
        * @var string
        */
        public $imageSrc = "";
        /**
        * @var string
        */
        public $icon = "";
        /**
        * @var string
        */
        public $canonical = "";
        /**
        * @var string
        */
        public $next = "";
        /**
        * @var string
        */
        public $prev = "";

        public $prettyPrint = false;      
        public function __construct ($format = false){
            $this->prettyPrint = $format;
        }
        /**
        * generate string for themeColor
        *
        * @return string
        */
        private function themeColorToString(){
            if($this->themeColor != ""){
                return  Utils::print_metaNC("theme-color",$this->themeColor);
            }
            return "";
            
        }
        /**
        * generate string for charset
        *
        * @return string
        */
        private function charsetToString(){
            if($this->charset != ""){
                return "<meta charset=\"$this->charset\">";
            }
            return "";
            
        }

        /**
        * generate string for title
        *
        * @return string
        */
        private function titleToString(){

            if($this->title != ""){
                $title =  htmlentities($this->title,ENT_QUOTES,"UTF-8");//str_replace( '"' , '\"' ,$this->title);
                return "<title>$title</title>";
            }
            return "";
            
        }
        /**
        * generate string for description
        *
        * @return string
        */
        private function descriptionToString(){
            
            if($this->description != ""){
                $description = htmlentities($this->description,ENT_QUOTES,"UTF-8"); //str_replace( '"' , '\"' ,$this->description);
                return  Utils::print_metaNC("description",$description);
            }
            return "";
            
        }
        /**
        * generate string for keywords
        *
        * @return string
        */
        private function keywordsToString(){
            if($this->keywords != ""){
                return Utils::print_metaNC("keywords",$this->keywords);
            }
            return "";
            
        }
        /**
        * generate string for author
        *
        * @return string
        */
        private function authorToString(){
            if($this->author != ""){
                return Utils::print_metaNC("author",htmlentities($this->author,ENT_QUOTES,"UTF-8"));
            }
            return "";
            
        }
        /**
        * generate string for image
        *
        * @return string
        */
        private function imageSrcToString(){
            if($this->imageSrc != ""){
                return Utils::print_linkRelHref("image_src",$this->imageSrc); //"<link rel=\"image_src\" href=\"$this->imageSrc\" >"; 
            }
            return "";
            
        }
        /**
        * generate string for canonical link
        *
        * @return string
        */
        private function canonicalSrcToString(){
            if($this->canonical != ""){
                return Utils::print_linkRelHref("canonical",$this->canonical); // "<link rel=\"canonical\" href=\"$this->canonical\"/>";
            }
            return "";
            
        }
        /**
        * generate string for next prev
        *
        * @return string
        */
        private function nextPrevToString(){
            $str = "";
            if($this->next != ""){
                $str.= Utils::print_linkRelHref("next",$this->next); // "<link rel=\"next\" href=\"$this->next\" >";
            }
            $str .= ($this->prettyPrint ? "\n" : "");
            if($this->prev != ""){
                $str.=  Utils::print_linkRelHref("prev",$this->prev); // "<link rel=\"prev\" href=\"$this->prev\" >";
            }
            return $str;
            
        }
        /**
        * generate string for next prev
        *
        * @return string
        */
        private function faviconToString(){
            $icon = "";
            $apple_touch_icon = ""; 
            if(is_array($this->icon)){
                foreach($this->icon as $key => $value){
                    if($key == "favicon") $icon = $value;
                    else if($key == "apple-touch-icon") $apple_touch_icon = $value;
                    else $icon = $value;
                }    
                if($icon != "" && $apple_touch_icon == ""){
                    $apple_touch_icon = $icon;
                }

            }else{
                $icon = $this->icon;
                $apple_touch_icon = $this->icon; 
            }
            if($icon != ""){
                return  Utils::print_linkRelHref("apple-touch-icon",$apple_touch_icon). // "<link rel=\"apple-touch-icon\" href=\"$apple_touch_icon\">". 
                        ($this->prettyPrint ? "\n" : "").
                        Utils::print_linkRelHref("icon",$icon). // "<link rel=\"icon\" href=\"$icon\">". 
                        ($this->prettyPrint ? "\n" : "").
                        "<!--[if IE]>".Utils::print_linkRelHref("shortcut icon",$icon)."<![endif]-->". 
                        ($this->prettyPrint ? "\n" : "").
                        ($this->themeColor != "" ? Utils::print_metaNC("msapplication-TileColor",$this->themeColor) : ""). 
                        ($this->prettyPrint ? "\n" : "").
                        Utils::print_metaNC("msapplication-TileImage",$apple_touch_icon);
                        //"<meta name=\"msapplication-TileImage\" content=\"$apple_touch_icon\">";
            }
        }
        /**
        * generate string for all generalMetadata
        *
        * @return string
        */
        public function toString(){
            return $this->themeColorToString(). ($this->prettyPrint ? "\n" : "").
                   $this->charsetToString(). ($this->prettyPrint ? "\n" : "").
                   $this->titleToString(). ($this->prettyPrint ? "\n" : "").
                   $this->descriptionToString(). ($this->prettyPrint ? "\n" : "").
                   $this->keywordsToString(). ($this->prettyPrint ? "\n" : "").
                   $this->authorToString(). ($this->prettyPrint ? "\n" : "").
                   $this->imageSrcToString(). ($this->prettyPrint ? "\n" : "").
                   $this->canonicalSrcToString(). ($this->prettyPrint ? "\n" : "").
                   $this->nextPrevToString().($this->prettyPrint ? "\n" : "").
                   $this->faviconToString();
        }
    }

?>