<?php namespace Helper\MetadataGenerator\StructuredData;



abstract class ContactType {
    const CostumerSupport = "customer support";
    const TechnicalSupport = "technical support";
    const BillingSupport = "billing support";
    const BillPayment = "bill payment";
    const Sales = "sales";
    const Reservations = "reservations";
    const CreditCardSupport = "credit card support";
    const Emergency = "emergency";
    const BaggageTracking = "baggage tracking";
    const RoadsideAssistance = "roadside assistance";
    const PackageTracking = "package tracking";

    private static $constCacheArray = NULL;
    
    private static function getConstants() {
        if (self::$constCacheArray == NULL) {
            self::$constCacheArray = array();
        }
        $calledClass = get_called_class();
        if (!array_key_exists($calledClass, self::$constCacheArray)) {
            $reflect = new \ReflectionClass($calledClass);
            self::$constCacheArray[$calledClass] = $reflect->getConstants();
        }
        return self::$constCacheArray[$calledClass];
    }

    public static function isValidName($name, $strict = false) {
        $constants = self::getConstants();

        if ($strict) {
            return array_key_exists($name, $constants);
        }

        $keys = array_map('strtolower', array_keys($constants));
        return in_array(strtolower($name), $keys);
    }

    public static function isValidValue($value, $strict = true) {
        $values = array_values(self::getConstants());
        return in_array($value, $values, $strict);
    }
}