<?php namespace Helper\MetadataGenerator\StructuredData\Organization;

use Helper\MetadataGenerator\StructuredData\JsonLDGenerator;
use Helper\MetadataGenerator\StructuredData\ContactType;

class OrganizationJsonLD extends JsonLDGenerator{


    public $url = "";
    public $social = array();
    public $logo = "";
    public $companyName = "";
    public $contacts = array(); // [phone , email , type]

    public $formated = 0;

    public function __construct($format = false){
      parent::__construct();
      $this->type = "Organization";
      $this->formated = $format ? 128 : 0;
    }

    public function toString(){
        $data = array();
        $data["@context"] = $this->context;
        $data["@type"]  = $this->type;
        $data["url"] = $this->url;
        $data["name"] = htmlentities($this->companyName,ENT_QUOTES,"UTF-8");
        $data["logo"] = $this->logo;
        $contacts = $this->printContacts($this->contacts);
        if(count($contacts) > 0){
            $data["contactPoint"] = $contacts;
        }

        return json_encode($data,$this->formated);
    }
    private function printContact($contact){
        if(is_array($contact) && count($contact)>0){

            $type = ContactType::isValidValue($contact["type"], $strict = true) ? $contact["type"] : "";
            if($type != ""){
                $c = array();
                $c["@type"] = "ContactPoint";
                $c["contactType"] = $type;
                $c["telephone"] = $contact["phone"];
                if( isset($contact["email"]) )
                    $c["email"] = $contact["email"];

                return $c;
            }

        }

        return null;
    }
    private function printContacts(){
        $contacts = array();
        if(count($this->contacts) > 0){
            foreach($this->contacts as $contact){
                $c = $this->printContact($contact);
                if($c != null){
                    array_push($contacts,$c);
                }
            }
        }
        return $contacts;
    }




    /*
    contactType
    "customer support", 
    "technical support", 
    "billing support", 
    "bill payment", 
    "sales", 
    "reservations", 
    "credit card support", 
    "emergency", 
    "baggage tracking", 
    "roadside assistance", 
    "package tracking"
    */
}